.. The master copy of this file is in the book repository. Don't edit its copy in
.. a slave repository.  See https://dev.lino-framework.org/writedocs/shared.html

.. |sliders-h|  image:: /../docs/shared/images/pi/sliders-h.svg
  :class: pi-button
  :alt: sliders-h

.. |eject|  image:: /../docs/shared/images/pi/eject.svg
  :class: pi-button
  :alt: eject

.. |bars|  image:: /../docs/shared/images/pi/bars.svg
  :class: pi-button
  :alt: bars button

.. |home|  image:: /../docs/shared/images/pi/home.svg
  :class: pi-button
  :alt: home button

.. |copy|  image:: /../docs/shared/images/pi/copy.svg
  :class: pi-button
  :alt: copy button

.. |save|  image:: /../docs/shared/images/pi/save.svg
  :class: pi-button
  :alt: save button

.. |external-link|  image:: /../docs/shared/images/pi/external-link.svg
  :class: pi-button
  :alt: external link

.. |filter|  image:: /../docs/shared/images/pi/filter.svg
  :class: pi-button
  :alt: filter button

.. |plus|  image:: /../docs/shared/images/pi/plus-circle.svg
  :class: pi-button
  :alt: plus-circle button

.. |trash|  image:: /../docs/shared/images/pi/trash.svg
  :class: pi-button
  :alt: trash button

.. |refresh|  image:: /../docs/shared/images/pi/refresh.svg
  :class: pi-button
  :alt: refresh button

.. |bell|  image:: /../docs/shared/images/pi/bell.svg
  :class: pi-button
  :alt: bell button

.. |user|  image:: /../docs/shared/images/pi/user.svg
  :class: pi-button
  :alt: user button

.. |close|  image:: /../docs/shared/images/pi/times-circle.svg
  :class: pi-button
  :alt: close button

.. |envelope|  image:: /../docs/shared/images/pi/envelope.svg
  :class: pi-button
  :alt: envelope button

.. |gear|  image:: /../docs/shared/images/buttons/gear.png
  :height: 1em

.. |flash|  image:: /../docs/shared/images/buttons/flash.png
  :height: 1em

.. |insert_old|  image:: /../docs/shared/images/buttons/insert.png
  :height: 1em

.. .. |eject|  image:: /../docs/shared/images/buttons/eject.png
  :height: 1em

.. |search|  image:: /../docs/shared/images/buttons/search.png
  :height: 1em

.. |merge|  image:: /../docs/shared/images/buttons/arrow_join.png
  :height: 1em

.. |lightning|  image:: https://gitlab.com/lino-framework/lino/-/raw/master/lino/static/images/mjames/lightning.png?inline=false
  :height: 1em

.. |delete|  image:: https://gitlab.com/lino-framework/lino/-/raw/master/lino/static/images/mjames/delete.png?inline=false
  :height: 1em

.. |insert|  image:: https://gitlab.com/lino-framework/lino/-/raw/master/lino/static/images/mjames/add.png?inline=false
  :height: 1em

.. |detail|  image:: https://gitlab.com/lino-framework/lino/-/raw/master/lino/static/images/mjames/application_form.png?inline=false
  :height: 1em

.. |basket|  image:: https://gitlab.com/lino-framework/lino/-/raw/master/lino/static/images/mjames/basket.png?inline=false
  :height: 1em

.. |money|  image:: https://gitlab.com/lino-framework/lino/-/raw/master/lino/static/images/mjames/money.png?inline=false
  :height: 1em

.. |print|  image:: https://gitlab.com/lino-framework/lino/-/raw/master/lino/static/images/mjames/printer.png?inline=false
  :height: 1em


.. .. |refresh|  image:: /../docs/shared/images/buttons/refresh.png
